@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -30,6 +30,8 @@
 #include <rtl/ustrbuf.hxx>
 #include <rtl/byteseq.hxx>
 
+#include <comphelper/sequenceasvector.hxx>
+
 #include <com/sun/star/xml/Attribute.hpp>
 #include <com/sun/star/xml/FastAttribute.hpp>
 #include <com/sun/star/xml/sax/XFastAttributeList.hpp>
@@ -40,6 +42,7 @@
 #include <cstdio>
 #endif
 
+using ::comphelper::SequenceAsVector;
 using ::rtl::OString;
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
@@ -87,7 +90,7 @@ namespace sax_fastparser {
     OUString FastSaxSerializer::escapeXml( const OUString& s )
     {
         ::rtl::OUStringBuffer sBuf( s.getLength() );
-        const sal_Unicode* pStr = s;
+        const sal_Unicode* pStr = s.getStr();
         sal_Int32 nLen = s.getLength();
         for( sal_Int32 i = 0; i < nLen; ++i)
         {
@@ -104,12 +107,12 @@ namespace sax_fastparser {
         }
         return sBuf.makeStringAndClear();
     }
-    
+
     void FastSaxSerializer::write( const OUString& s )
     {
         OString sOutput( OUStringToOString( s, RTL_TEXTENCODING_UTF8 ) );
-        writeBytes( Sequence< sal_Int8 >( 
-                    reinterpret_cast< const sal_Int8*>( sOutput.getStr() ), 
+        writeBytes( Sequence< sal_Int8 >(
+                    reinterpret_cast< const sal_Int8*>( sOutput.getStr() ),
                     sOutput.getLength() ) );
     }
 
@@ -118,7 +121,7 @@ namespace sax_fastparser {
         if (!mxOutputStream.is())
             return;
     }
-    
+
     void SAL_CALL FastSaxSerializer::writeId( ::sal_Int32 nElement )
     {
         if( HAS_NAMESPACE( nElement ) ) {
@@ -135,6 +138,9 @@ namespace sax_fastparser {
         if (!mxOutputStream.is())
             return;
 
+        if ( !maMarkStack.empty() )
+            maMarkStack.top()->setCurrentElement( Element );
+
         writeBytes(toUnoSequence(aOpeningBracket));
 
         writeId(Element);
@@ -156,11 +162,11 @@ namespace sax_fastparser {
             write(Namespace);
             writeBytes(toUnoSequence(aColon));
         }
-        
+
         write(Name);
-        
+
         writeFastAttributeList(Attribs);
-            
+
         writeBytes(toUnoSequence(aClosingBracket));
     }
 
@@ -190,9 +196,9 @@ namespace sax_fastparser {
             write(Namespace);
             writeBytes(toUnoSequence(aColon));
         }
-        
+
         write(Name);
-        
+
         writeBytes(toUnoSequence(aClosingBracket));
     }
 
@@ -202,6 +208,9 @@ namespace sax_fastparser {
         if (!mxOutputStream.is())
             return;
 
+        if ( !maMarkStack.empty() )
+            maMarkStack.top()->setCurrentElement( Element );
+
         writeBytes(toUnoSequence(aOpeningBracket));
 
         writeId(Element);
@@ -223,11 +232,11 @@ namespace sax_fastparser {
             write(Namespace);
             writeBytes(toUnoSequence(aColon));
         }
-        
+
         write(Name);
 
         writeFastAttributeList(Attribs);
-            
+
         writeBytes(toUnoSequence(aSlashAndClosingBracket));
     }
 
@@ -239,7 +248,7 @@ namespace sax_fastparser {
 
         write( aChars );
     }
-    
+
     void SAL_CALL FastSaxSerializer::setOutputStream( const ::com::sun::star::uno::Reference< ::com::sun::star::io::XOutputStream >& xOutputStream )
         throw (::com::sun::star::uno::RuntimeException)
     {
@@ -265,7 +274,7 @@ namespace sax_fastparser {
             write(escapeXml(pAttr[i].Value));
             writeBytes(toUnoSequence(aQuote));
         }
-        
+
         Sequence< FastAttribute > aFastAttrSeq = Attribs->getFastAttributes();
         const FastAttribute *pFastAttr = aFastAttrSeq.getConstArray();
         sal_Int32 nFastAttrLength = aFastAttrSeq.getLength();
@@ -275,11 +284,11 @@ namespace sax_fastparser {
 
             sal_Int32 nToken = pFastAttr[j].Token;
             writeId(nToken);
-            
+
             writeBytes(toUnoSequence(aEqualSignAndQuote));
-    
+
             write(escapeXml(Attribs->getValue(pFastAttr[j].Token)));
-            
+
             writeBytes(toUnoSequence(aQuote));
         }
     }
@@ -287,7 +296,7 @@ namespace sax_fastparser {
     // XServiceInfo
     OUString FastSaxSerializer::getImplementationName() throw (RuntimeException)
     {
-        return OUString::createFromAscii( SERIALIZER_IMPLEMENTATION_NAME );
+        return OUString(RTL_CONSTASCII_USTRINGPARAM( SERIALIZER_IMPLEMENTATION_NAME ));
     }
 
     // XServiceInfo
@@ -307,13 +316,13 @@ namespace sax_fastparser {
     Sequence< OUString > FastSaxSerializer::getSupportedServiceNames(void) throw (RuntimeException)
     {
         Sequence<OUString> seq(1);
-        seq.getArray()[0] = OUString::createFromAscii( SERIALIZER_SERVICE_NAME );
+        seq.getArray()[0] = OUString(RTL_CONSTASCII_USTRINGPARAM( SERIALIZER_SERVICE_NAME ));
         return seq;
     }
 
     OUString FastSaxSerializer::getImplementationName_Static()
     {
-        return OUString::createFromAscii( SERIALIZER_IMPLEMENTATION_NAME );
+        return OUString(RTL_CONSTASCII_USTRINGPARAM( SERIALIZER_IMPLEMENTATION_NAME ));
     }
 
     Sequence< OUString > FastSaxSerializer::getSupportedServiceNames_Static(void)
@@ -323,24 +332,31 @@ namespace sax_fastparser {
         return aRet;
     }
 
-    void FastSaxSerializer::mark()
+    void FastSaxSerializer::mark( Int32Sequence aOrder )
     {
-        maMarkStack.push( ForMerge() );
+        if ( aOrder.hasElements() )
+        {
+            boost::shared_ptr< ForMerge > pSort( new ForSort( aOrder ) );
+            maMarkStack.push( pSort );
+        }
+        else
+        {
+            boost::shared_ptr< ForMerge > pMerge( new ForMerge( ) );
+            maMarkStack.push( pMerge );
+        }
     }
 
 #if DEBUG
     void FastSaxSerializer::printMarkStack( )
     {
-        ::std::stack< ForMerge > aCopy( maMarkStack );
+        ::std::stack< boost::shared_ptr< ForMerge > > aCopy( maMarkStack );
         int nSize = aCopy.size();
         int i = 0;
         while ( !aCopy.empty() )
         {
             fprintf( stderr, "%d\n", nSize - i );
 
-            ForMerge aMarks = aCopy.top( );
-            aMarks.print();
-
+            aCopy.top( )->print( );
 
             fprintf( stderr, "\n" );
 
@@ -357,19 +373,19 @@ namespace sax_fastparser {
 
         if ( maMarkStack.size() == 1 )
         {
-            mxOutputStream->writeBytes( maMarkStack.top().getData() );
+            mxOutputStream->writeBytes( maMarkStack.top()->getData() );
             maMarkStack.pop();
             return;
         }
 
-        const Int8Sequence aMerge( maMarkStack.top().getData() );
+        const Int8Sequence aMerge( maMarkStack.top()->getData() );
         maMarkStack.pop();
 
         switch ( eMergeType )
         {
-            case MERGE_MARKS_APPEND:   maMarkStack.top().append( aMerge );   break;
-            case MERGE_MARKS_PREPEND:  maMarkStack.top().prepend( aMerge );  break;
-            case MERGE_MARKS_POSTPONE: maMarkStack.top().postpone( aMerge ); break;
+            case MERGE_MARKS_APPEND:   maMarkStack.top()->append( aMerge );   break;
+            case MERGE_MARKS_PREPEND:  maMarkStack.top()->prepend( aMerge );  break;
+            case MERGE_MARKS_POSTPONE: maMarkStack.top()->postpone( aMerge ); break;
         }
     }
 
@@ -378,14 +394,14 @@ namespace sax_fastparser {
         if ( maMarkStack.empty() )
             mxOutputStream->writeBytes( aData );
         else
-            maMarkStack.top().append( aData );
+            maMarkStack.top()->append( aData );
     }
 
     FastSaxSerializer::Int8Sequence& FastSaxSerializer::ForMerge::getData()
     {
         merge( maData, maPostponed, true );
         maPostponed.realloc( 0 );
-        
+
         return maData;
     }
 
@@ -445,6 +461,71 @@ namespace sax_fastparser {
         }
     }
 
+    void FastSaxSerializer::ForMerge::resetData( )
+    {
+        maData = Int8Sequence();
+    }
+
+    void FastSaxSerializer::ForSort::setCurrentElement( sal_Int32 nElement )
+    {
+        SequenceAsVector< sal_Int32 > aOrder( maOrder );
+        if( std::find( aOrder.begin(), aOrder.end(), nElement ) != aOrder.end() )
+        {
+            mnCurrentElement = nElement;
+            if ( maData.find( nElement ) == maData.end() )
+                maData[ nElement ] = Int8Sequence();
+        }
+    }
+
+    void FastSaxSerializer::ForSort::prepend( const Int8Sequence &rWhat )
+    {
+        append( rWhat );
+    }
+
+    void FastSaxSerializer::ForSort::append( const Int8Sequence &rWhat )
+    {
+        merge( maData[mnCurrentElement], rWhat, true );
+    }
+
+    void FastSaxSerializer::ForSort::sort()
+    {
+        // Clear the ForMerge data to avoid duplicate items
+        resetData();
+
+        // Sort it all
+        std::map< sal_Int32, Int8Sequence >::iterator iter;
+        for ( sal_Int32 i=0, len=maOrder.getLength(); i < len; i++ )
+        {
+            iter = maData.find( maOrder[i] );
+            if ( iter != maData.end() )
+                ForMerge::append( iter->second );
+        }
+    }
+
+    FastSaxSerializer::Int8Sequence& FastSaxSerializer::ForSort::getData()
+    {
+        sort( );
+        return ForMerge::getData();
+    }
+
+#if DEBUG
+    void FastSaxSerializer::ForSort::print( )
+    {
+        std::map< sal_Int32, Int8Sequence >::iterator iter = maData.begin();
+        while ( iter != maData.end( ) )
+        {
+            fprintf( stderr, "pair: %d, ", iter->first );
+            for ( sal_Int32 i=0, len=iter->second.getLength(); i < len; ++i )
+                fprintf( stderr, "%c", iter->second[i] );
+            fprintf( stderr, "\n" );
+            ++iter;
+        }
+
+        sort( );
+        ForMerge::print();
+    }
+#endif
+
 } // namespace sax_fastparser
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
