@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -44,27 +45,13 @@
 #include <unotools/cacheoptions.hxx>
 #include <svtools/grfmgr.hxx>
 
-// --> OD 2010-01-04 #i105243#
 #include <vcl/pdfextoutdevdata.hxx>
-// <--
-
-// -----------
-// - Defines -
-// -----------
 
 #define WATERMARK_LUM_OFFSET				50
 #define WATERMARK_CON_OFFSET				-70
 
-// -----------
-// - statics -
-// -----------
-
 GraphicManager* GraphicObject::mpGlobalMgr = NULL;
 
-// ---------------------
-// - GrfDirectCacheObj -
-// ---------------------
-
 struct GrfSimpleCacheObj
 {
     Graphic		maGraphic;
@@ -74,14 +61,8 @@ struct GrfSimpleCacheObj
                     maGraphic( rGraphic ), maAttr( rAttr ) {}
 };
 
-// -----------------
-// - GraphicObject -
-// -----------------
-
 TYPEINIT1_AUTOFACTORY( GraphicObject, SvDataCopyStream );
 
-// -----------------------------------------------------------------------------
-
 GraphicObject::GraphicObject( const GraphicManager* pMgr ) :
     mpLink		( NULL ),
     mpUserData	( NULL )
@@ -91,8 +72,6 @@ GraphicObject::GraphicObject( const GraphicManager* pMgr ) :
     ImplSetGraphicManager( pMgr );
 }
 
-// -----------------------------------------------------------------------------
-
 GraphicObject::GraphicObject( const Graphic& rGraphic, const GraphicManager* pMgr ) :
     maGraphic	( rGraphic ),
     mpLink		( NULL ),
@@ -103,8 +82,6 @@ GraphicObject::GraphicObject( const Graphic& rGraphic, const GraphicManager* pMg
     ImplSetGraphicManager( pMgr );
 }
 
-// -----------------------------------------------------------------------------
-
 GraphicObject::GraphicObject( const Graphic& rGraphic, const String& rLink, const GraphicManager* pMgr ) :
     maGraphic	( rGraphic ),
     mpLink		( rLink.Len() ? ( new String( rLink ) ) : NULL ),
@@ -115,8 +92,6 @@ GraphicObject::GraphicObject( const Graphic& rGraphic, const String& rLink, cons
     ImplSetGraphicManager( pMgr );
 }
 
-// -----------------------------------------------------------------------------
-
 GraphicObject::GraphicObject( const GraphicObject& rGraphicObj, const GraphicManager* pMgr ) :
     SvDataCopyStream(),
     maGraphic	( rGraphicObj.GetGraphic() ),
@@ -129,8 +104,6 @@ GraphicObject::GraphicObject( const GraphicObject& rGraphicObj, const GraphicMan
     ImplSetGraphicManager( pMgr, NULL, &rGraphicObj );
 }
 
-// -----------------------------------------------------------------------------
-
 GraphicObject::GraphicObject( const ByteString& rUniqueID, const GraphicManager* pMgr ) :
     mpLink		( NULL ),
     mpUserData	( NULL )
@@ -146,8 +119,6 @@ GraphicObject::GraphicObject( const ByteString& rUniqueID, const GraphicManager*
     ImplAssignGraphicData();
 }
 
-// -----------------------------------------------------------------------------
-
 GraphicObject::~GraphicObject()
 {
     if( mpMgr )
@@ -165,8 +136,6 @@ GraphicObject::~GraphicObject()
     delete mpSimpleCache;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::ImplConstruct()
 {
     mpMgr = NULL;
@@ -174,13 +143,11 @@ void GraphicObject::ImplConstruct()
     mpSwapOutTimer = NULL;
     mpSimpleCache = NULL;
     mnAnimationLoopCount = 0;
-    mbAutoSwapped = FALSE;
-    mbIsInSwapIn = FALSE;
-    mbIsInSwapOut = FALSE;
+    mbAutoSwapped = sal_False;
+    mbIsInSwapIn = sal_False;
+    mbIsInSwapOut = sal_False;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::ImplAssignGraphicData()
 {
     maPrefSize = maGraphic.GetPrefSize();
@@ -198,11 +165,9 @@ void GraphicObject::ImplAssignGraphicData()
         mbEPS = ( rMtf.GetActionCount() >= 1 ) && ( META_EPS_ACTION == rMtf.GetAction( 0 )->GetType() );
     }
     else
-        mbEPS = FALSE;
+        mbEPS = sal_False;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::ImplSetGraphicManager( const GraphicManager* pMgr, const ByteString* pID, const GraphicObject* pCopyObj )
 {
     if( !mpMgr || ( pMgr != mpMgr ) )
@@ -240,20 +205,18 @@ void GraphicObject::ImplSetGraphicManager( const GraphicManager* pMgr, const Byt
     }
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::ImplAutoSwapIn()
 {
     if( IsSwappedOut() )
     {
         if( mpMgr && mpMgr->ImplFillSwappedGraphicObject( *this, maGraphic ) )
-            mbAutoSwapped = FALSE;
+            mbAutoSwapped = sal_False;
         else
         {
-            mbIsInSwapIn = TRUE;
+            mbIsInSwapIn = sal_True;
 
             if( maGraphic.SwapIn() )
-                mbAutoSwapped = FALSE;
+                mbAutoSwapped = sal_False;
             else
             {
                 SvStream* pStream = GetSwapStream();
@@ -296,7 +259,7 @@ void GraphicObject::ImplAutoSwapIn()
                 }
             }
 
-            mbIsInSwapIn = FALSE;
+            mbIsInSwapIn = sal_False;
 
             if( !mbAutoSwapped && mpMgr )
                 mpMgr->ImplGraphicObjectWasSwappedIn( *this );
@@ -304,20 +267,16 @@ void GraphicObject::ImplAutoSwapIn()
     }
 }
 
-// -----------------------------------------------------------------------------
-BOOL GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz, const GraphicAttr* pAttr,
-                                       PolyPolygon& rClipPolyPoly, BOOL& bRectClipRegion ) const
+sal_Bool GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz, const GraphicAttr* pAttr,
+                                       PolyPolygon& rClipPolyPoly, sal_Bool& bRectClipRegion ) const
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if( GetType() != GRAPHIC_NONE )
     {
         Polygon			aClipPoly( Rectangle( rPt, rSz ) );
-        const USHORT	nRot10 = pAttr->GetRotation() % 3600;
+        const sal_uInt16	nRot10 = pAttr->GetRotation() % 3600;
         const Point		aOldOrigin( rPt );
-        // --> OD 2005-09-30 #i54875# - It's not needed to get the graphic again.
-//        const Graphic&  rGraphic = GetGraphic();
-        // <--
         const MapMode	aMap100( MAP_100TH_MM );
         Size			aSize100;
         long			nTotalWidth, nTotalHeight;
@@ -327,19 +286,13 @@ BOOL GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz
         if( nRot10 )
         {
             aClipPoly.Rotate( rPt, nRot10 );
-            bRectClipRegion = FALSE;
+            bRectClipRegion = sal_False;
         }
         else
-            bRectClipRegion = TRUE;
+            bRectClipRegion = sal_True;
 
         rClipPolyPoly = aClipPoly;
 
-        // --> OD 2005-09-30 #i54875# - directly access member <maGraphic> to
-        // get <PrefSize> and <PrefMapMode>.
-//        if( rGraphic.GetPrefMapMode() == MAP_PIXEL )
-//            aSize100 = Application::GetDefaultDevice()->PixelToLogic( rGraphic.GetPrefSize(), aMap100 );
-//        else
-//            aSize100 = pOut->LogicToLogic( rGraphic.GetPrefSize(), rGraphic.GetPrefMapMode(), aMap100 );
         if( maGraphic.GetPrefMapMode() == MAP_PIXEL )
             aSize100 = Application::GetDefaultDevice()->PixelToLogic( maGraphic.GetPrefSize(), aMap100 );
         else
@@ -379,15 +332,13 @@ BOOL GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz
                 rPt = aOriginPoly[ 0 ];
             }
 
-            bRet = TRUE;
+            bRet = sal_True;
         }
     }
 
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
 GraphicObject& GraphicObject::operator=( const GraphicObject& rGraphicObj )
 {
     if( &rGraphicObj != this )
@@ -404,7 +355,7 @@ GraphicObject& GraphicObject::operator=( const GraphicObject& rGraphicObj )
         mpLink = rGraphicObj.mpLink ? new String( *rGraphicObj.mpLink ) : NULL;
         mpUserData = rGraphicObj.mpUserData ? new String( *rGraphicObj.mpUserData ) : NULL;
         ImplAssignGraphicData();
-        mbAutoSwapped = FALSE;
+        mbAutoSwapped = sal_False;
         mpMgr = rGraphicObj.mpMgr;
 
         mpMgr->ImplRegisterObj( *this, maGraphic, NULL, &rGraphicObj );
@@ -413,38 +364,28 @@ GraphicObject& GraphicObject::operator=( const GraphicObject& rGraphicObj )
     return *this;
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::operator==( const GraphicObject& rGraphicObj ) const
+sal_Bool GraphicObject::operator==( const GraphicObject& rGraphicObj ) const
 {
     return(	( rGraphicObj.maGraphic == maGraphic ) &&
             ( rGraphicObj.maAttr == maAttr ) &&
             ( rGraphicObj.GetLink() == GetLink() ) );
 }
 
-// ------------------------------------------------------------------------
-
 void GraphicObject::Load( SvStream& rIStm )
 {
     rIStm >> *this;
 }
 
-// ------------------------------------------------------------------------
-
 void GraphicObject::Save( SvStream& rOStm )
 {
     rOStm << *this;
 }
 
-// ------------------------------------------------------------------------
-
 void GraphicObject::Assign( const SvDataCopyStream& rCopyStream )
 {
     *this = (const GraphicObject& ) rCopyStream;
 }
 
-// -----------------------------------------------------------------------------
-
 ByteString GraphicObject::GetUniqueID() const
 {
     if ( !IsInSwapIn() && IsEPS() )
@@ -458,30 +399,22 @@ ByteString GraphicObject::GetUniqueID() const
     return aRet;
 }
 
-// -----------------------------------------------------------------------------
-
-ULONG GraphicObject::GetChecksum() const
+sal_uLong GraphicObject::GetChecksum() const
 {
     return( ( maGraphic.IsSupportedGraphic() && !maGraphic.IsSwapOut() ) ? maGraphic.GetChecksum() : 0 );
 }
 
-// -----------------------------------------------------------------------------
-
 SvStream* GraphicObject::GetSwapStream() const
 {
     return( HasSwapStreamHdl() ? (SvStream*) mpSwapStreamHdl->Call( (void*) this ) : GRFMGR_AUTOSWAPSTREAM_NONE );
 }
 
-// -----------------------------------------------------------------------------
-
 // !!! to be removed
-ULONG GraphicObject::GetReleaseFromCache() const
+sal_uLong GraphicObject::GetReleaseFromCache() const
 {
     return 0;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetAttr( const GraphicAttr& rAttr )
 {
     maAttr = rAttr;
@@ -490,23 +423,17 @@ void GraphicObject::SetAttr( const GraphicAttr& rAttr )
         delete mpSimpleCache, mpSimpleCache = NULL;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetLink()
 {
     if( mpLink )
         delete mpLink, mpLink = NULL;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetLink( const String& rLink )
 {
     delete mpLink, mpLink = new String( rLink );
 }
 
-// -----------------------------------------------------------------------------
-
 String GraphicObject::GetLink() const
 {
     if( mpLink )
@@ -515,23 +442,17 @@ String GraphicObject::GetLink() const
         return String();
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetUserData()
 {
     if( mpUserData )
         delete mpUserData, mpUserData = NULL;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetUserData( const String& rUserData )
 {
     delete mpUserData, mpUserData = new String( rUserData );
 }
 
-// -----------------------------------------------------------------------------
-
 String GraphicObject::GetUserData() const
 {
     if( mpUserData )
@@ -540,8 +461,6 @@ String GraphicObject::GetUserData() const
         return String();
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetSwapStreamHdl()
 {
     if( mpSwapStreamHdl )
@@ -551,9 +470,7 @@ void GraphicObject::SetSwapStreamHdl()
     }
 }
 
-// -----------------------------------------------------------------------------
-
-void GraphicObject::SetSwapStreamHdl( const Link& rHdl, const ULONG nSwapOutTimeout )
+void GraphicObject::SetSwapStreamHdl( const Link& rHdl, const sal_uLong nSwapOutTimeout )
 {
     delete mpSwapStreamHdl,	mpSwapStreamHdl = new Link( rHdl );
 
@@ -572,8 +489,6 @@ void GraphicObject::SetSwapStreamHdl( const Link& rHdl, const ULONG nSwapOutTime
         delete mpSwapOutTimer, mpSwapOutTimer = NULL;
 }
 
-// -----------------------------------------------------------------------------
-
 Link GraphicObject::GetSwapStreamHdl() const
 {
     if( mpSwapStreamHdl )
@@ -582,22 +497,16 @@ Link GraphicObject::GetSwapStreamHdl() const
         return Link();
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::FireSwapInRequest()
 {
     ImplAutoSwapIn();
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::FireSwapOutRequest()
 {
     ImplAutoSwapOutHdl( NULL );
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::GraphicManagerDestroyed()
 {
     // we're alive, but our manager doesn't live anymore ==> connect to default manager
@@ -605,76 +514,60 @@ void GraphicObject::GraphicManagerDestroyed()
     ImplSetGraphicManager( NULL );
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetGraphicManager( const GraphicManager& rMgr )
 {
     ImplSetGraphicManager( &rMgr );
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::IsCached( OutputDevice* pOut, const Point& rPt, const Size& rSz,
-                              const GraphicAttr* pAttr, ULONG nFlags ) const
+sal_Bool GraphicObject::IsCached( OutputDevice* pOut, const Point& rPt, const Size& rSz,
+                              const GraphicAttr* pAttr, sal_uLong nFlags ) const
 {
-    BOOL bRet;
+    sal_Bool bRet;
 
     if( nFlags & GRFMGR_DRAW_CACHED )
     {
-        // --> OD 2005-10-11 #i54875# - Consider cropped graphics.
-        // Note: The graphic manager caches a cropped graphic with its
-        //       uncropped position and size.
-//        bRet = mpMgr->IsInCache( pOut, rPt, rSz, *this, ( pAttr ? *pAttr : GetAttr() ) );
         Point aPt( rPt );
         Size aSz( rSz );
         if ( pAttr->IsCropped() )
         {
             PolyPolygon aClipPolyPoly;
-            BOOL        bRectClip;
+            sal_Bool        bRectClip;
             ImplGetCropParams( pOut, aPt, aSz, pAttr, aClipPolyPoly, bRectClip );
         }
         bRet = mpMgr->IsInCache( pOut, aPt, aSz, *this, ( pAttr ? *pAttr : GetAttr() ) );
     }
     else
-        bRet = FALSE;
+        bRet = sal_False;
 
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::ReleaseFromCache()
 {
 
     mpMgr->ReleaseFromCache( *this );
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetAnimationNotifyHdl( const Link& rLink )
 {
     maGraphic.SetAnimationNotifyHdl( rLink );
 }
 
-// -----------------------------------------------------------------------------
-
 List* GraphicObject::GetAnimationInfoList() const
 {
     return maGraphic.GetAnimationInfoList();
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
-                          const GraphicAttr* pAttr, ULONG nFlags )
+sal_Bool GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
+                          const GraphicAttr* pAttr, sal_uLong nFlags )
 {
     GraphicAttr	        aAttr( pAttr ? *pAttr : GetAttr() );
     Point 		        aPt( rPt );
     Size  	            aSz( rSz );
     const sal_uInt32    nOldDrawMode = pOut->GetDrawMode();
-    BOOL		        bCropped = aAttr.IsCropped();
-    BOOL		        bCached = FALSE;
-    BOOL		        bRet;
+    sal_Bool		        bCropped = aAttr.IsCropped();
+    sal_Bool		        bCached = sal_False;
+    sal_Bool		        bRet;
 
     // #i29534# Provide output rects for PDF writer
     Rectangle			aCropRect;
@@ -701,8 +594,8 @@ BOOL GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
     if( bCropped )
     {
         PolyPolygon aClipPolyPoly;
-        BOOL		bRectClip;
-        const BOOL	bCrop = ImplGetCropParams( pOut, aPt, aSz, &aAttr, aClipPolyPoly, bRectClip );
+        sal_Bool		bRectClip;
+        const sal_Bool	bCrop = ImplGetCropParams( pOut, aPt, aSz, &aAttr, aClipPolyPoly, bRectClip );
 
         pOut->Push( PUSH_CLIPREGION );
 
@@ -742,11 +635,11 @@ BOOL GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
     return bRet;
 }
 
-// --> OD 2010-01-04 #i105243#
-BOOL GraphicObject::DrawWithPDFHandling( OutputDevice& rOutDev,
+// #i105243#
+sal_Bool GraphicObject::DrawWithPDFHandling( OutputDevice& rOutDev,
                                          const Point& rPt, const Size& rSz,
                                          const GraphicAttr* pGrfAttr,
-                                         const ULONG nFlags )
+                                         const sal_uLong nFlags )
 {
     const GraphicAttr aGrfAttr( pGrfAttr ? *pGrfAttr : GetAttr() );
 
@@ -773,8 +666,8 @@ BOOL GraphicObject::DrawWithPDFHandling( OutputDevice& rOutDev,
             if( aGrfAttr.IsCropped() )
             {
                 PolyPolygon aClipPolyPoly;
-                BOOL bRectClip;
-                const BOOL bCrop = ImplGetCropParams( &rOutDev,
+                sal_Bool bRectClip;
+                const sal_Bool bCrop = ImplGetCropParams( &rOutDev,
                                                       aPt, aSz,
                                                       &aGrfAttr,
                                                       aClipPolyPoly,
@@ -789,7 +682,7 @@ BOOL GraphicObject::DrawWithPDFHandling( OutputDevice& rOutDev,
         }
     }
 
-    BOOL bRet = Draw( &rOutDev, rPt, rSz, &aGrfAttr, nFlags );
+    sal_Bool bRet = Draw( &rOutDev, rPt, rSz, &aGrfAttr, nFlags );
 
     // Notify PDF writer about linked graphic (if any)
     if( bWritingPdfLinkedGraphic )
@@ -802,15 +695,12 @@ BOOL GraphicObject::DrawWithPDFHandling( OutputDevice& rOutDev,
 
     return bRet;
 }
-// <--
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::DrawTiled( OutputDevice* pOut, const Rectangle& rArea, const Size& rSize,
-                               const Size& rOffset, const GraphicAttr* pAttr, ULONG nFlags, int nTileCacheSize1D )
+sal_Bool GraphicObject::DrawTiled( OutputDevice* pOut, const Rectangle& rArea, const Size& rSize,
+                               const Size& rOffset, const GraphicAttr* pAttr, sal_uLong nFlags, int nTileCacheSize1D )
 {
     if( pOut == NULL || rSize.Width() == 0 || rSize.Height() == 0 )
-        return FALSE;
+        return sal_False;
 
     const MapMode 	aOutMapMode( pOut->GetMapMode() );
     const MapMode	aMapMode( aOutMapMode.GetMapUnit(), Point(), aOutMapMode.GetScaleX(), aOutMapMode.GetScaleY() );
@@ -828,13 +718,11 @@ BOOL GraphicObject::DrawTiled( OutputDevice* pOut, const Rectangle& rArea, const
     return ImplDrawTiled( pOut, rArea, aOutTileSize, rOffset, pAttr, nFlags, nTileCacheSize1D );
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const Size& rSz,
-                                    long nExtraData, const GraphicAttr* pAttr, ULONG /*nFlags*/,
+sal_Bool GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const Size& rSz,
+                                    long nExtraData, const GraphicAttr* pAttr, sal_uLong /*nFlags*/,
                                     OutputDevice* pFirstFrameOutDev )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     GetGraphic();
 
@@ -846,13 +734,13 @@ BOOL GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
         {
             Point   aPt( rPt );
             Size	aSz( rSz );
-            BOOL	bCropped = aAttr.IsCropped();
+            sal_Bool	bCropped = aAttr.IsCropped();
 
             if( bCropped )
             {
                 PolyPolygon aClipPolyPoly;
-                BOOL		bRectClip;
-                const BOOL	bCrop = ImplGetCropParams( pOut, aPt, aSz, &aAttr, aClipPolyPoly, bRectClip );
+                sal_Bool		bRectClip;
+                const sal_Bool	bCrop = ImplGetCropParams( pOut, aPt, aSz, &aAttr, aClipPolyPoly, bRectClip );
 
                 pOut->Push( PUSH_CLIPREGION );
 
@@ -879,7 +767,7 @@ BOOL GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
             if( bCropped )
                 pOut->Pop();
 
-            bRet = TRUE;
+            bRet = sal_True;
         }
         else
             bRet = Draw( pOut, rPt, rSz, &aAttr, GRFMGR_DRAW_STANDARD );
@@ -888,16 +776,12 @@ BOOL GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::StopAnimation( OutputDevice* pOut, long nExtraData )
 {
     if( mpSimpleCache )
         mpSimpleCache->maGraphic.StopAnimation( pOut, nExtraData );
 }
 
-// -----------------------------------------------------------------------------
-
 const Graphic& GraphicObject::GetGraphic() const
 {
     if( mbAutoSwapped )
@@ -906,8 +790,6 @@ const Graphic& GraphicObject::GetGraphic() const
     return maGraphic;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetGraphic( const Graphic& rGraphic, const GraphicObject* pCopyObj )
 {
     mpMgr->ImplUnregisterObj( *this );
@@ -916,7 +798,7 @@ void GraphicObject::SetGraphic( const Graphic& rGraphic, const GraphicObject* pC
         mpSwapOutTimer->Stop();
 
     maGraphic = rGraphic;
-    mbAutoSwapped = FALSE;
+    mbAutoSwapped = sal_False;
     ImplAssignGraphicData();
     delete mpLink, mpLink = NULL;
     delete mpSimpleCache, mpSimpleCache = NULL;
@@ -927,16 +809,12 @@ void GraphicObject::SetGraphic( const Graphic& rGraphic, const GraphicObject* pC
         mpSwapOutTimer->Start();
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetGraphic( const Graphic& rGraphic, const String& rLink )
 {
     SetGraphic( rGraphic );
     mpLink = new String( rLink );
 }
 
-// -----------------------------------------------------------------------------
-
 Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMode& rDestMap, const GraphicAttr& rAttr ) const
 {
     // #104550# Extracted from svx/source/svdraw/svdograf.cxx
@@ -1042,7 +920,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
         // #105641# Also crop animations
         if( aTransGraphic.IsAnimated() )
         {
-            USHORT nFrame;
+            sal_uInt16 nFrame;
             Animation aAnim( aTransGraphic.GetAnimation() );
 
             for( nFrame=0; nFrame<aAnim.Count(); ++nFrame )
@@ -1059,7 +937,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
                     // cropping affects this frame, apply it then
                     // do _not_ apply enlargement, this is done below
                     ImplTransformBitmap( aAnimBmp.aBmpEx, rAttr, Size(), Size(),
-                                         aCropRectRel, rDestSize, FALSE );
+                                         aCropRectRel, rDestSize, sal_False );
 
                     aAnim.Replace( aAnimBmp, nFrame );
                 }
@@ -1106,7 +984,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
             BitmapEx aBmpEx( aTransGraphic.GetBitmapEx() );
 
             ImplTransformBitmap( aBmpEx, rAttr, aCropLeftTop, aCropRightBottom,
-                                 aCropRect, rDestSize, TRUE );
+                                 aCropRect, rDestSize, sal_True );
 
             aTransGraphic = aBmpEx;
         }
@@ -1121,8 +999,6 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
     return aTransGraphic;
 }
 
-// -----------------------------------------------------------------------------
-
 Graphic GraphicObject::GetTransformedGraphic( const GraphicAttr* pAttr ) const // TODO: Change to Impl
 {
     GetGraphic();
@@ -1173,8 +1049,6 @@ Graphic GraphicObject::GetTransformedGraphic( const GraphicAttr* pAttr ) const /
     return aGraphic;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::ResetAnimationLoopCount()
 {
     if( IsAnimated() && !IsSwappedOut() )
@@ -1186,11 +1060,9 @@ void GraphicObject::ResetAnimationLoopCount()
     }
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::SwapOut()
+sal_Bool GraphicObject::SwapOut()
 {
-    BOOL bRet = ( !mbAutoSwapped ? maGraphic.SwapOut() : FALSE );
+    sal_Bool bRet = ( !mbAutoSwapped ? maGraphic.SwapOut() : sal_False );
 
     if( bRet && mpMgr )
         mpMgr->ImplGraphicObjectWasSwappedOut( *this );
@@ -1198,11 +1070,9 @@ BOOL GraphicObject::SwapOut()
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::SwapOut( SvStream* pOStm )
+sal_Bool GraphicObject::SwapOut( SvStream* pOStm )
 {
-    BOOL bRet = ( !mbAutoSwapped ? maGraphic.SwapOut( pOStm ) : FALSE );
+    sal_Bool bRet = ( !mbAutoSwapped ? maGraphic.SwapOut( pOStm ) : sal_False );
 
     if( bRet && mpMgr )
         mpMgr->ImplGraphicObjectWasSwappedOut( *this );
@@ -1210,19 +1080,17 @@ BOOL GraphicObject::SwapOut( SvStream* pOStm )
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::SwapIn()
+sal_Bool GraphicObject::SwapIn()
 {
-    BOOL bRet;
+    sal_Bool bRet;
 
     if( mbAutoSwapped )
     {
         ImplAutoSwapIn();
-        bRet = TRUE;
+        bRet = sal_True;
     }
     else if( mpMgr && mpMgr->ImplFillSwappedGraphicObject( *this, maGraphic ) )
-        bRet = TRUE;
+        bRet = sal_True;
     else
     {
         bRet = maGraphic.SwapIn();
@@ -1237,19 +1105,17 @@ BOOL GraphicObject::SwapIn()
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
-BOOL GraphicObject::SwapIn( SvStream* pIStm )
+sal_Bool GraphicObject::SwapIn( SvStream* pIStm )
 {
-    BOOL bRet;
+    sal_Bool bRet;
 
     if( mbAutoSwapped )
     {
         ImplAutoSwapIn();
-        bRet = TRUE;
+        bRet = sal_True;
     }
     else if( mpMgr && mpMgr->ImplFillSwappedGraphicObject( *this, maGraphic ) )
-        bRet = TRUE;
+        bRet = sal_True;
     else
     {
         bRet = maGraphic.SwapIn( pIStm );
@@ -1264,26 +1130,22 @@ BOOL GraphicObject::SwapIn( SvStream* pIStm )
     return bRet;
 }
 
-// -----------------------------------------------------------------------------
-
 void GraphicObject::SetSwapState()
 {
     if( !IsSwappedOut() )
     {
-        mbAutoSwapped = TRUE;
+        mbAutoSwapped = sal_True;
 
         if( mpMgr )
             mpMgr->ImplGraphicObjectWasSwappedOut( *this );
     }
 }
 
-// -----------------------------------------------------------------------------
-
 IMPL_LINK( GraphicObject, ImplAutoSwapOutHdl, void*, EMPTYARG )
 {
     if( !IsSwappedOut() )
     {
-        mbIsInSwapOut = TRUE;
+        mbIsInSwapOut = sal_True;
 
         SvStream* pStream = GetSwapStream();
 
@@ -1303,7 +1165,7 @@ IMPL_LINK( GraphicObject, ImplAutoSwapOutHdl, void*, EMPTYARG )
             }
         }
 
-        mbIsInSwapOut = FALSE;
+        mbIsInSwapOut = sal_False;
     }
 
     if( mpSwapOutTimer )
@@ -1312,15 +1174,13 @@ IMPL_LINK( GraphicObject, ImplAutoSwapOutHdl, void*, EMPTYARG )
     return 0L;
 }
 
-// ------------------------------------------------------------------------
-
 SvStream& operator>>( SvStream& rIStm, GraphicObject& rGraphicObj )
 {
     VersionCompat	aCompat( rIStm, STREAM_READ );
     Graphic			aGraphic;
     GraphicAttr		aAttr;
     ByteString		aLink;
-    BOOL			bLink;
+    sal_Bool			bLink;
 
     rIStm >> aGraphic >> aAttr >> bLink;
 
@@ -1340,12 +1200,10 @@ SvStream& operator>>( SvStream& rIStm, GraphicObject& rGraphicObj )
     return rIStm;
 }
 
-// ------------------------------------------------------------------------
-
 SvStream& operator<<( SvStream& rOStm, const GraphicObject& rGraphicObj )
 {
     VersionCompat	aCompat( rOStm, STREAM_WRITE, 1 );
-    const BOOL		bLink =  rGraphicObj.HasLink();
+    const sal_Bool		bLink =  rGraphicObj.HasLink();
 
     rOStm << rGraphicObj.GetGraphic() << rGraphicObj.GetAttr() << bLink;
 
@@ -1359,7 +1217,7 @@ SvStream& operator<<( SvStream& rOStm, const GraphicObject& rGraphicObj )
 
 GraphicObject GraphicObject::CreateGraphicObjectFromURL( const ::rtl::OUString &rURL )
 {
-    const String aURL( rURL ), aPrefix( RTL_CONSTASCII_STRINGPARAM(UNO_NAME_GRAPHOBJ_URLPREFIX) );
+    const String aURL( rURL ), aPrefix( RTL_CONSTASCII_USTRINGPARAM(UNO_NAME_GRAPHOBJ_URLPREFIX) );
     if( aURL.Search( aPrefix ) == 0 )
     {
         // graphic manager url
@@ -1380,3 +1238,4 @@ GraphicObject GraphicObject::CreateGraphicObjectFromURL( const ::rtl::OUString &
     }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
