@@ -40,6 +40,7 @@
 
 #include <vcl/unohelp.hxx>
 #include <tools/debug.hxx>
+#include <tools/resary.hxx>
 #include <tools/stream.hxx>
 #include <tools/vcompat.hxx>
 #include <vcl/svdata.hxx>
@@ -53,11 +54,18 @@
 #include <vcl/gdimtf.hxx>
 #include <vcl/metaact.hxx>
 #include <vcl/print.hxx>
+#include <vcl/svids.hrc>
 
 #include <comphelper/processfactory.hxx>
 
+#include "com/sun/star/beans/XPropertySet.hpp"
+#include "com/sun/star/container/XNameAccess.hpp"
+#include "com/sun/star/lang/XMultiServiceFactory.hpp"
+
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
+using namespace com::sun::star::beans;
+using namespace com::sun::star::container;
 
 int nImplSysDialog = 0;
 
@@ -110,16 +118,16 @@ void ImplUpdateJobSetupPaper( JobSetup& rJobSetup )
 // ------------------
 
 PrinterOptions::PrinterOptions() :
-    mbReduceTransparency( FALSE ),
+    mbReduceTransparency( sal_False ),
     meReducedTransparencyMode( PRINTER_TRANSPARENCY_AUTO ),
-    mbReduceGradients( FALSE ),
+    mbReduceGradients( sal_False ),
     meReducedGradientsMode( PRINTER_GRADIENT_STRIPES ),
     mnReducedGradientStepCount( 64 ),
-    mbReduceBitmaps( FALSE ),
+    mbReduceBitmaps( sal_False ),
     meReducedBitmapMode( PRINTER_BITMAP_NORMAL ),
     mnReducedBitmapResolution( 200 ),
-    mbReducedBitmapsIncludeTransparency( TRUE ),
-    mbConvertToGreyscales( FALSE )
+    mbReducedBitmapsIncludeTransparency( sal_True ),
+    mbConvertToGreyscales( sal_False )
 {
 }
 
@@ -129,6 +137,105 @@ PrinterOptions::~PrinterOptions()
 {
 }
 
+#define	PROPERTYNAME_REDUCETRANSPARENCY	                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReduceTransparency"))
+#define	PROPERTYNAME_REDUCEDTRANSPARENCYMODE	        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReducedTransparencyMode"))
+#define	PROPERTYNAME_REDUCEGRADIENTS		            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReduceGradients"))
+#define	PROPERTYNAME_REDUCEDGRADIENTMODE		        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReducedGradientMode"))
+#define PROPERTYNAME_REDUCEDGRADIENTSTEPCOUNT           rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReducedGradientStepCount"))
+#define PROPERTYNAME_REDUCEBITMAPS                      rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReduceBitmaps"))
+#define PROPERTYNAME_REDUCEDBITMAPMODE                  rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReducedBitmapMode"))
+#define PROPERTYNAME_REDUCEDBITMAPRESOLUTION            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReducedBitmapResolution"))
+#define PROPERTYNAME_REDUCEDBITMAPINCLUDESTRANSPARENCY  rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ReducedBitmapIncludesTransparency"))
+#define PROPERTYNAME_CONVERTTOGREYSCALES                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ConvertToGreyscales"))
+
+bool PrinterOptions::ReadFromConfig( bool i_bFile )
+{
+    bool bSuccess = false;
+    // save old state in case something goes wrong
+    PrinterOptions aOldValues( *this );
+    
+    // get the configuration service
+    Reference< XMultiServiceFactory > xConfigProvider;
+    Reference< XNameAccess > xConfigAccess;
+    try
+    {
+        // get service provider
+        Reference< XMultiServiceFactory > xSMgr( comphelper::getProcessServiceFactory() );
+        // create configuration hierachical access name
+        if( xSMgr.is() )
+        {
+            try
+            {
+                xConfigProvider = Reference< XMultiServiceFactory >(
+                        xSMgr->createInstance( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
+                                        "com.sun.star.configuration.ConfigurationProvider" ))),
+                        UNO_QUERY );
+                if( xConfigProvider.is() )
+                {
+                    Sequence< Any > aArgs(1);
+                    PropertyValue aVal;
+                    aVal.Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ) );
+                    if( i_bFile )
+                        aVal.Value <<= rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.Office.Common/Print/Option/File" ) );
+                    else
+                        aVal.Value <<= rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.Office.Common/Print/Option/Printer" ) );
+                    aArgs.getArray()[0] <<= aVal;
+                    xConfigAccess = Reference< XNameAccess >(
+                            xConfigProvider->createInstanceWithArguments(
+                                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationAccess" )), aArgs ),
+                                UNO_QUERY );
+                    if( xConfigAccess.is() )
+                    {
+                        Reference< XPropertySet > xSet( xConfigAccess, UNO_QUERY );
+                        if( xSet.is() )
+                        {
+                            sal_Int32 nValue = 0;
+                            sal_Bool  bValue = 0;
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCETRANSPARENCY) >>= bValue )
+                                SetReduceTransparency( bValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEDTRANSPARENCYMODE) >>= nValue )
+                                SetReducedTransparencyMode( (PrinterTransparencyMode)nValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEGRADIENTS) >>= bValue )
+                                SetReduceGradients( bValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEDGRADIENTMODE) >>= nValue )
+                                SetReducedGradientMode( (PrinterGradientMode)nValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEDGRADIENTSTEPCOUNT) >>= nValue )
+                                SetReducedGradientStepCount( (sal_uInt16)nValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEBITMAPS) >>= bValue )
+                                SetReduceBitmaps( bValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEDBITMAPMODE) >>= nValue )
+                                SetReducedBitmapMode( (PrinterBitmapMode)nValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEDBITMAPRESOLUTION) >>= nValue )
+                                SetReducedBitmapResolution( (sal_uInt16)nValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_REDUCEDBITMAPINCLUDESTRANSPARENCY) >>= bValue )
+                                SetReducedBitmapIncludesTransparency( bValue );
+                            if( xSet->getPropertyValue(PROPERTYNAME_CONVERTTOGREYSCALES) >>= bValue )
+                                SetConvertToGreyscales( bValue );
+                            
+                            bSuccess = true;
+                        }
+                    }
+                }
+            }
+            catch( Exception& )
+            {
+            }
+        }
+    }
+    catch( WrappedTargetException& )
+    {
+    }
+    
+    if( ! bSuccess )
+        *this = aOldValues;
+    return bSuccess;
+}
+
+void Printer::SetPrinterOptions( const PrinterOptions& i_rOptions )
+{
+    *mpPrinterOptions = i_rOptions;
+}
+
 // -------------
 // - QueueInfo -
 // -------------
@@ -233,7 +340,7 @@ ImplPrnQueueList::~ImplPrnQueueList()
 
 void ImplPrnQueueList::Add( SalPrinterQueueInfo* pData )
 {
-    std::hash_map< rtl::OUString, sal_Int32, rtl::OUStringHash >::iterator it =
+    boost::unordered_map< rtl::OUString, sal_Int32, rtl::OUStringHash >::iterator it =
         m_aNameToIndex.find( pData->maPrinterName );
     if( it == m_aNameToIndex.end() )
     {
@@ -258,7 +365,7 @@ void ImplPrnQueueList::Add( SalPrinterQueueInfo* pData )
 ImplPrnQueueData* ImplPrnQueueList::Get( const rtl::OUString& rPrinter )
 {
     ImplPrnQueueData* pData = NULL;
-    std::hash_map<rtl::OUString,sal_Int32,rtl::OUStringHash>::iterator it =
+    boost::unordered_map<rtl::OUString,sal_Int32,rtl::OUStringHash>::iterator it =
         m_aNameToIndex.find( rPrinter );
     if( it != m_aNameToIndex.end() )
         pData = &m_aQueueInfos[it->second];
@@ -348,24 +455,24 @@ XubString Printer::GetDefaultPrinterName()
 
 void Printer::ImplInitData()
 {
-    mbDevOutput 		= FALSE;
+    mbDevOutput 		= sal_False;
     meOutDevType		= OUTDEV_PRINTER;
-    mbDefPrinter		= FALSE;
+    mbDefPrinter		= sal_False;
     mnError 			= 0;
     mnCurPage			= 0;
     mnCurPrintPage		= 0;
     mnPageQueueSize 	= 0;
     mnCopyCount 		= 1;
-    mbCollateCopy		= FALSE;
-    mbPrinting			= FALSE;
-    mbJobActive 		= FALSE;
-    mbPrintFile 		= FALSE;
-    mbInPrintPage		= FALSE;
-    mbNewJobSetup		= FALSE;
+    mbCollateCopy		= sal_False;
+    mbPrinting			= sal_False;
+    mbJobActive 		= sal_False;
+    mbPrintFile 		= sal_False;
+    mbInPrintPage		= sal_False;
+    mbNewJobSetup		= sal_False;
     mpInfoPrinter		= NULL;
     mpPrinter			= NULL;
     mpDisplayDev		= NULL;
-    mbIsQueuePrinter	= FALSE;
+    mbIsQueuePrinter	= sal_False;
     mpPrinterOptions    = new PrinterOptions;
 
     // Printer in die Liste eintragen
@@ -430,7 +537,7 @@ void Printer::ImplInit( SalPrinterQueueInfo* pInfo )
     // Daten initialisieren
     ImplUpdatePageData();
     mpFontList = new ImplDevFontList();
-    mpFontCache = new ImplFontCache( TRUE );
+    mpFontCache = new ImplFontCache( sal_True );
     mpGraphics->GetDevFontList( mpFontList );
 }
 
@@ -539,7 +646,7 @@ void Printer::ImplUpdatePageData()
 
 void Printer::ImplUpdateFontList()
 {
-    ImplUpdateFontData( TRUE );
+    ImplUpdateFontData( sal_True );
 }
 
 // -----------------------------------------------------------------------
@@ -552,7 +659,7 @@ Printer::Printer()
     {
         ImplInit( pInfo );
         if ( !IsDisplayPrinter() )
-            mbDefPrinter = TRUE;
+            mbDefPrinter = sal_True;
     }
     else
         ImplInitDisplay( NULL );
@@ -670,57 +777,57 @@ void Printer::Compat_OldPrinterMetrics( bool bSet )
         mpInfoPrinter->m_bCompatMetrics = bSet;
 
     // get new font data
-    ImplUpdateFontData( TRUE );
+    ImplUpdateFontData( sal_True );
 }
 
 // -----------------------------------------------------------------------
 
-ULONG Printer::GetCapabilities( USHORT nType ) const
+sal_uLong Printer::GetCapabilities( sal_uInt16 nType ) const
 {
     if ( IsDisplayPrinter() )
-        return FALSE;
+        return sal_False;
 
     if( mpInfoPrinter )
         return mpInfoPrinter->GetCapabilities( maJobSetup.ImplGetConstData(), nType );
     else
-        return FALSE;
+        return sal_False;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::HasSupport( PrinterSupport eFeature ) const
+sal_Bool Printer::HasSupport( PrinterSupport eFeature ) const
 {
     switch ( eFeature )
     {
         case SUPPORT_SET_ORIENTATION:
-            return (BOOL)GetCapabilities( PRINTER_CAPABILITIES_SETORIENTATION );
+            return (sal_Bool)GetCapabilities( PRINTER_CAPABILITIES_SETORIENTATION );
         case SUPPORT_SET_PAPERBIN:
-            return (BOOL)GetCapabilities( PRINTER_CAPABILITIES_SETPAPERBIN );
+            return (sal_Bool)GetCapabilities( PRINTER_CAPABILITIES_SETPAPERBIN );
         case SUPPORT_SET_PAPERSIZE:
-            return (BOOL)GetCapabilities( PRINTER_CAPABILITIES_SETPAPERSIZE );
+            return (sal_Bool)GetCapabilities( PRINTER_CAPABILITIES_SETPAPERSIZE );
         case SUPPORT_SET_PAPER:
-            return (BOOL)GetCapabilities( PRINTER_CAPABILITIES_SETPAPER );
+            return (sal_Bool)GetCapabilities( PRINTER_CAPABILITIES_SETPAPER );
         case SUPPORT_COPY:
             return (GetCapabilities( PRINTER_CAPABILITIES_COPIES ) != 0);
         case SUPPORT_COLLATECOPY:
             return (GetCapabilities( PRINTER_CAPABILITIES_COLLATECOPIES ) != 0);
         case SUPPORT_SETUPDIALOG:
-            return (BOOL)GetCapabilities( PRINTER_CAPABILITIES_SUPPORTDIALOG );
+            return (sal_Bool)GetCapabilities( PRINTER_CAPABILITIES_SUPPORTDIALOG );
         case SUPPORT_FAX:
-            return (BOOL) GetCapabilities( PRINTER_CAPABILITIES_FAX );
+            return (sal_Bool) GetCapabilities( PRINTER_CAPABILITIES_FAX );
         case SUPPORT_PDF:
-            return (BOOL) GetCapabilities( PRINTER_CAPABILITIES_PDF );
+            return (sal_Bool) GetCapabilities( PRINTER_CAPABILITIES_PDF );
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetJobSetup( const JobSetup& rSetup )
+sal_Bool Printer::SetJobSetup( const JobSetup& rSetup )
 {
     if ( IsDisplayPrinter() || mbInPrintPage )
-        return FALSE;
+        return sal_False;
 
     JobSetup aJobSetup = rSetup;
 
@@ -728,60 +835,60 @@ BOOL Printer::SetJobSetup( const JobSetup& rSetup )
     if ( mpInfoPrinter->SetPrinterData( aJobSetup.ImplGetData() ) )
     {
         ImplUpdateJobSetupPaper( aJobSetup );
-        mbNewJobSetup = TRUE;
+        mbNewJobSetup = sal_True;
         maJobSetup = aJobSetup;
         ImplUpdatePageData();
         ImplUpdateFontList();
-        return TRUE;
+        return sal_True;
     }
 
-    return FALSE;
+    return sal_False;
 }
 
 // -----------------------------------------------------------------------
 
 
-BOOL Printer::Setup( Window* pWindow )
+sal_Bool Printer::Setup( Window* pWindow )
 {
     if ( IsDisplayPrinter() )
-        return FALSE;
+        return sal_False;
 
     if ( IsJobActive() || IsPrinting() )
-        return FALSE;
+        return sal_False;
 
     JobSetup aJobSetup = maJobSetup;
     SalFrame* pFrame;
     if ( !pWindow )
         pWindow = ImplGetDefaultWindow();
     if( !pWindow )
-        return FALSE;
+        return sal_False;
 
     pFrame = pWindow->ImplGetFrame();
     ImplReleaseGraphics();
     ImplSVData* pSVData = ImplGetSVData();
     pSVData->maAppData.mnModalMode++;
     nImplSysDialog++;
-    BOOL bSetup = mpInfoPrinter->Setup( pFrame, aJobSetup.ImplGetData() );
+    sal_Bool bSetup = mpInfoPrinter->Setup( pFrame, aJobSetup.ImplGetData() );
     pSVData->maAppData.mnModalMode--;
     nImplSysDialog--;
     if ( bSetup )
     {
         ImplUpdateJobSetupPaper( aJobSetup );
-        mbNewJobSetup = TRUE;
+        mbNewJobSetup = sal_True;
         maJobSetup = aJobSetup;
         ImplUpdatePageData();
         ImplUpdateFontList();
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetPrinterProps( const Printer* pPrinter )
+sal_Bool Printer::SetPrinterProps( const Printer* pPrinter )
 {
     if ( IsJobActive() || IsPrinting() )
-        return FALSE;
+        return sal_False;
 
     ImplSVData* pSVData = ImplGetSVData();
 
@@ -821,14 +928,14 @@ BOOL Printer::SetPrinterProps( const Printer* pPrinter )
             mpFontCache = NULL;
             mpFontList = NULL;
 
-            mbInitFont = TRUE;
-            mbNewFont = TRUE;
+            mbInitFont = sal_True;
+            mbNewFont = sal_True;
             mpInfoPrinter = NULL;
         }
 
         // Neuen Printer bauen
         ImplInitDisplay( NULL );
-        return TRUE;
+        return sal_True;
     }
 
     // Alten Printer zerstoeren?
@@ -863,8 +970,8 @@ BOOL Printer::SetPrinterProps( const Printer* pPrinter )
             delete mpFontList;
             mpFontCache = NULL;
             mpFontList = NULL;
-            mbInitFont = TRUE;
-            mbNewFont = TRUE;
+            mbInitFont = sal_True;
+            mbNewFont = sal_True;
             mpInfoPrinter = NULL;
         }
 
@@ -882,15 +989,15 @@ BOOL Printer::SetPrinterProps( const Printer* pPrinter )
     else
         SetJobSetup( pPrinter->GetJobSetup() );
 
-    return FALSE;
+    return sal_False;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetOrientation( Orientation eOrientation )
+sal_Bool Printer::SetOrientation( Orientation eOrientation )
 {
     if ( mbInPrintPage )
-        return FALSE;
+        return sal_False;
 
     if ( maJobSetup.ImplGetConstData()->meOrientation != eOrientation )
     {
@@ -900,26 +1007,26 @@ BOOL Printer::SetOrientation( Orientation eOrientation )
 
         if ( IsDisplayPrinter() )
         {
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
-            return TRUE;
+            return sal_True;
         }
 
         ImplReleaseGraphics();
         if ( mpInfoPrinter->SetData( SAL_JOBSET_ORIENTATION, pSetupData ) )
         {
             ImplUpdateJobSetupPaper( aJobSetup );
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
             ImplUpdatePageData();
             ImplUpdateFontList();
-            return TRUE;
+            return sal_True;
         }
         else
-            return FALSE;
+            return sal_False;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
@@ -931,10 +1038,10 @@ Orientation Printer::GetOrientation() const
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetPaperBin( USHORT nPaperBin )
+sal_Bool Printer::SetPaperBin( sal_uInt16 nPaperBin )
 {
     if ( mbInPrintPage )
-        return FALSE;
+        return sal_False;
 
     if ( (maJobSetup.ImplGetConstData()->mnPaperBin != nPaperBin) &&
          (nPaperBin < GetPaperBinCount()) )
@@ -945,31 +1052,31 @@ BOOL Printer::SetPaperBin( USHORT nPaperBin )
 
         if ( IsDisplayPrinter() )
         {
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
-            return TRUE;
+            return sal_True;
         }
 
         ImplReleaseGraphics();
         if ( mpInfoPrinter->SetData( SAL_JOBSET_PAPERBIN, pSetupData ) )
         {
             ImplUpdateJobSetupPaper( aJobSetup );
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
             ImplUpdatePageData();
             ImplUpdateFontList();
-            return TRUE;
+            return sal_True;
         }
         else
-            return FALSE;
+            return sal_False;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
 
-USHORT Printer::GetPaperBin() const
+sal_uInt16 Printer::GetPaperBin() const
 {
     return maJobSetup.ImplGetConstData()->mnPaperBin;
 }
@@ -1067,10 +1174,10 @@ void Printer::ImplFindPaperFormatForUserSize( JobSetup& aJobSetup, bool bMatchNe
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetPaper( Paper ePaper )
+sal_Bool Printer::SetPaper( Paper ePaper )
 {
     if ( mbInPrintPage )
-        return FALSE;
+        return sal_False;
 
     if ( maJobSetup.ImplGetConstData()->mePaperFormat != ePaper )
     {
@@ -1086,9 +1193,9 @@ BOOL Printer::SetPaper( Paper ePaper )
 
         if ( IsDisplayPrinter() )
         {
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
-            return TRUE;
+            return sal_True;
         }
 
         ImplReleaseGraphics();
@@ -1097,30 +1204,30 @@ BOOL Printer::SetPaper( Paper ePaper )
         if ( mpInfoPrinter->SetData( SAL_JOBSET_PAPERSIZE|SAL_JOBSET_ORIENTATION, pSetupData ) )
         {
             ImplUpdateJobSetupPaper( aJobSetup );
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
             ImplUpdatePageData();
             ImplUpdateFontList();
-            return TRUE;
+            return sal_True;
         }
         else
-            return FALSE;
+            return sal_False;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetPaperSizeUser( const Size& rSize )
+sal_Bool Printer::SetPaperSizeUser( const Size& rSize )
 {
     return SetPaperSizeUser( rSize, false );
 }
 
-BOOL Printer::SetPaperSizeUser( const Size& rSize, bool bMatchNearest )
+sal_Bool Printer::SetPaperSizeUser( const Size& rSize, bool bMatchNearest )
 {
     if ( mbInPrintPage )
-        return FALSE;
+        return sal_False;
 
     Size	aPixSize = LogicToPixel( rSize );
     Size	aPageSize = PixelToLogic( aPixSize, MAP_100TH_MM );
@@ -1136,9 +1243,9 @@ BOOL Printer::SetPaperSizeUser( const Size& rSize, bool bMatchNearest )
 
         if ( IsDisplayPrinter() )
         {
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
-            return TRUE;
+            return sal_True;
         }
 
         ImplReleaseGraphics();
@@ -1148,17 +1255,17 @@ BOOL Printer::SetPaperSizeUser( const Size& rSize, bool bMatchNearest )
         if ( mpInfoPrinter->SetData( SAL_JOBSET_PAPERSIZE|SAL_JOBSET_ORIENTATION, pSetupData ) )
         {
             ImplUpdateJobSetupPaper( aJobSetup );
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
             ImplUpdatePageData();
             ImplUpdateFontList();
-            return TRUE;
+            return sal_True;
         }
         else
-            return FALSE;
+            return sal_False;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
@@ -1174,6 +1281,48 @@ int Printer::GetPaperInfoCount() const
 
 // -----------------------------------------------------------------------
 
+rtl::OUString Printer::GetPaperName( Paper ePaper )
+{
+    ImplSVData* pSVData = ImplGetSVData();
+    if( ! pSVData->mpPaperNames )
+    {
+        pSVData->mpPaperNames = new boost::unordered_map< int, rtl::OUString >();
+        if( ImplGetResMgr() )
+        {
+            ResStringArray aPaperStrings( VclResId( RID_STR_PAPERNAMES ) );
+            static const int PaperIndex[] =
+            {
+                PAPER_A0, PAPER_A1, PAPER_A2, PAPER_A3, PAPER_A4, PAPER_A5,
+                PAPER_B4_ISO, PAPER_B5_ISO, PAPER_LETTER, PAPER_LEGAL, PAPER_TABLOID,
+                PAPER_USER, PAPER_B6_ISO, PAPER_ENV_C4, PAPER_ENV_C5, PAPER_ENV_C6, PAPER_ENV_C65,
+                PAPER_ENV_DL, PAPER_SLIDE_DIA, PAPER_SCREEN, PAPER_C, PAPER_D, PAPER_E,
+                PAPER_EXECUTIVE, PAPER_FANFOLD_LEGAL_DE, PAPER_ENV_MONARCH, PAPER_ENV_PERSONAL,
+                PAPER_ENV_9, PAPER_ENV_10, PAPER_ENV_11, PAPER_ENV_12, PAPER_KAI16,
+                PAPER_KAI32, PAPER_KAI32BIG, PAPER_B4_JIS, PAPER_B5_JIS, PAPER_B6_JIS
+            };
+            OSL_ENSURE( sal_uInt32(sizeof(PaperIndex)/sizeof(PaperIndex[0])) == aPaperStrings.Count(), "localized paper name count wrong" );
+            for( int i = 0; i < int(sizeof(PaperIndex)/sizeof(PaperIndex[0])); i++ )
+                (*pSVData->mpPaperNames)[PaperIndex[i]] = aPaperStrings.GetString(i);
+        }
+    }
+    
+    boost::unordered_map<int,rtl::OUString>::const_iterator it = pSVData->mpPaperNames->find( (int)ePaper );
+    return (it != pSVData->mpPaperNames->end()) ? it->second : rtl::OUString();
+}
+
+// -----------------------------------------------------------------------
+
+rtl::OUString Printer::GetPaperName( bool i_bPaperUser ) const
+{
+    Size  aPageSize = PixelToLogic( GetPaperSizePixel(), MAP_100TH_MM );
+    Paper ePaper    = ImplGetPaperFormat( aPageSize.Width(), aPageSize.Height() );
+    if( ePaper == PAPER_USER )
+        ePaper = ImplGetPaperFormat( aPageSize.Height(), aPageSize.Width() );
+    return (ePaper != PAPER_USER || i_bPaperUser ) ? GetPaperName( ePaper ) : rtl::OUString();
+}
+
+// -----------------------------------------------------------------------
+
 const PaperInfo& Printer::GetPaperInfo( int nPaper ) const
 {
     if( ! mpInfoPrinter )
@@ -1194,10 +1343,10 @@ DuplexMode Printer::GetDuplexMode() const
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetDuplexMode( DuplexMode eDuplex )
+sal_Bool Printer::SetDuplexMode( DuplexMode eDuplex )
 {
     if ( mbInPrintPage )
-        return FALSE;
+        return sal_False;
 
     if ( maJobSetup.ImplGetConstData()->meDuplexMode != eDuplex )
     {
@@ -1207,26 +1356,26 @@ BOOL Printer::SetDuplexMode( DuplexMode eDuplex )
 
         if ( IsDisplayPrinter() )
         {
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
-            return TRUE;
+            return sal_True;
         }
 
         ImplReleaseGraphics();
         if ( mpInfoPrinter->SetData( SAL_JOBSET_DUPLEXMODE, pSetupData ) )
         {
             ImplUpdateJobSetupPaper( aJobSetup );
-            mbNewJobSetup = TRUE;
+            mbNewJobSetup = sal_True;
             maJobSetup = aJobSetup;
             ImplUpdatePageData();
             ImplUpdateFontList();
-            return TRUE;
+            return sal_True;
         }
         else
-            return FALSE;
+            return sal_False;
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
@@ -1245,17 +1394,17 @@ Paper Printer::GetPaper() const
 
 // -----------------------------------------------------------------------
 
-USHORT Printer::GetPaperBinCount() const
+sal_uInt16 Printer::GetPaperBinCount() const
 {
     if ( IsDisplayPrinter() )
         return 0;
 
-    return (USHORT)mpInfoPrinter->GetPaperBinCount( maJobSetup.ImplGetConstData() );
+    return (sal_uInt16)mpInfoPrinter->GetPaperBinCount( maJobSetup.ImplGetConstData() );
 }
 
 // -----------------------------------------------------------------------
 
-XubString Printer::GetPaperBinName( USHORT nPaperBin ) const
+XubString Printer::GetPaperBinName( sal_uInt16 nPaperBin ) const
 {
     if ( IsDisplayPrinter() )
         return ImplGetSVEmptyStr();
@@ -1268,11 +1417,11 @@ XubString Printer::GetPaperBinName( USHORT nPaperBin ) const
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::SetCopyCount( USHORT nCopy, BOOL bCollate )
+sal_Bool Printer::SetCopyCount( sal_uInt16 nCopy, sal_Bool bCollate )
 {
     mnCopyCount = nCopy;
     mbCollateCopy = bCollate;
-    return TRUE;
+    return sal_True;
 }
 
 // -----------------------------------------------------------------------
@@ -1285,9 +1434,9 @@ void Printer::Error()
 // -----------------------------------------------------------------------
 
 
-ULONG Printer::ImplSalPrinterErrorCodeToVCL( ULONG nError )
+sal_uLong Printer::ImplSalPrinterErrorCodeToVCL( sal_uLong nError )
 {
-    ULONG nVCLError;
+    sal_uLong nVCLError;
     switch ( nError )
     {
         case 0:
@@ -1308,7 +1457,7 @@ ULONG Printer::ImplSalPrinterErrorCodeToVCL( ULONG nError )
 
 void Printer::ImplEndPrint()
 {
-    mbPrinting		= FALSE;
+    mbPrinting		= sal_False;
     mnCurPrintPage	= 0;
     maJobName.Erase();
 }
@@ -1325,15 +1474,15 @@ IMPL_LINK( Printer, ImplDestroyPrinterAsync, void*, pSalPrinter )
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::EndJob()
+sal_Bool Printer::EndJob()
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     if ( !IsJobActive() )
         return bRet;
 
     DBG_ASSERT( !mbInPrintPage, "Printer::EndJob() - StartPage() without EndPage() called" );
 
-    mbJobActive = FALSE;
+    mbJobActive = sal_False;
 
     if ( mpPrinter )
     {
@@ -1341,13 +1490,13 @@ BOOL Printer::EndJob()
 
         mnCurPage = 0;
 
-        bRet = TRUE;
+        bRet = sal_True;
 
-        mbPrinting		= FALSE;
+        mbPrinting		= sal_False;
         mnCurPrintPage	= 0;
         maJobName.Erase();
 
-        mbDevOutput = FALSE;
+        mbDevOutput = sal_False;
         bRet = mpPrinter->EndJob();
         // Hier den Drucker nicht asyncron zerstoeren, da es
         // W95 nicht verkraftet, wenn gleichzeitig gedruckt wird
@@ -1361,34 +1510,34 @@ BOOL Printer::EndJob()
 
 // -----------------------------------------------------------------------
 
-BOOL Printer::AbortJob()
+sal_Bool Printer::AbortJob()
 {
     // Wenn wir einen Queue-Printer haben, kann man diesen noch mit
     // AbortJob() abbrechen, solange dieser noch am Drucken ist
     if ( !IsJobActive() && !IsPrinting() )
-        return FALSE;
+        return sal_False;
 
-    mbJobActive 	= FALSE;
-    mbInPrintPage	= FALSE;
+    mbJobActive 	= sal_False;
+    mbInPrintPage	= sal_False;
     mpJobGraphics	= NULL;
 
     if ( mpPrinter )
     {
-        mbPrinting		= FALSE;
+        mbPrinting		= sal_False;
         mnCurPage		= 0;
         mnCurPrintPage	= 0;
         maJobName.Erase();
 
         ImplReleaseGraphics();
-        mbDevOutput = FALSE;
+        mbDevOutput = sal_False;
         mpPrinter->AbortJob();
         Application::PostUserEvent( LINK( this, Printer, ImplDestroyPrinterAsync ), mpPrinter );
         mpPrinter = NULL;
 
-        return TRUE;
+        return sal_True;
     }
 
-    return FALSE;
+    return sal_False;
 }
 
 // -----------------------------------------------------------------------
@@ -1406,12 +1555,12 @@ void Printer::ImplStartPage()
             ImplReleaseGraphics();
             mpJobGraphics = pGraphics;
         }
-        mbDevOutput = TRUE;
+        mbDevOutput = sal_True;
 
         // PrintJob not aborted ???
         if ( IsJobActive() )
         {
-            mbInPrintPage = TRUE;
+            mbInPrintPage = sal_True;
             mnCurPage++;
             mnCurPrintPage++;
         }
@@ -1425,16 +1574,16 @@ void Printer::ImplEndPage()
     if ( !IsJobActive() )
         return;
 
-    mbInPrintPage = FALSE;
+    mbInPrintPage = sal_False;
 
     if ( mpPrinter )
     {
         mpPrinter->EndPage();
         ImplReleaseGraphics();
-        mbDevOutput = FALSE;
+        mbDevOutput = sal_False;
 
         mpJobGraphics = NULL;
-        mbNewJobSetup = FALSE;
+        mbNewJobSetup = sal_False;
     }
 }
 
